@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2012 The Cacti Group                                 |
+ | Copyright (C) 2004-2017 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -24,19 +24,18 @@
  */
 
 /* do NOT run this script through a web browser */
-if (!isset($_SERVER["argv"][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die("<br><strong>This script is only meant to run at the command line.</strong>");
+if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
+	die('<br><strong>This script is only meant to run at the command line.</strong>');
 }
 
 $no_http_headers = true;
 
-include(dirname(__FILE__)."/../include/global.php");
-include_once($config["base_path"]."/lib/api_automation_tools.php");
-include_once($config["base_path"].'/lib/tree.php');
-include_once($config["base_path"].'/lib/api_tree.php');
+include(dirname(__FILE__).'/../include/global.php');
+include_once($config['base_path'].'/lib/api_automation_tools.php');
+include_once($config['base_path'].'/lib/api_tree.php');
 
 /* process calling arguments */
-$parms = $_SERVER["argv"];
+$parms = $_SERVER['argv'];
 array_shift($parms);
 
 if (sizeof($parms)) {
@@ -48,7 +47,6 @@ if (sizeof($parms)) {
 	$treeId     = 0;   # When creating a node, it has to go in a tree
 	$nodeType   = '';  # Should be 'header', 'graph' or 'host' when creating a node
 	$graphId    = 0;   # The ID of the graph to add (gets added to parentNode)
-	$rra_id     = 1;   # The rra_id for the graph to display: 1 = daily, 2 = weekly, 3 = monthly, 4 = yearly
 
 	$sortMethods = array('manual' => 1, 'alpha' => 2, 'natural' => 4, 'numeric' => 3);
 	$nodeTypes   = array('header' => 1, 'graph' => 2, 'host' => 3);
@@ -66,83 +64,84 @@ if (sizeof($parms)) {
 	$hosts          = getHosts();
 
 	foreach($parms as $parameter) {
-		@list($arg, $value) = @explode("=", $parameter);
+		if (strpos($parameter, '=')) {
+			list($arg, $value) = explode('=', $parameter);
+		} else {
+			$arg = $parameter;
+			$value = '';
+		}
 
 		switch ($arg) {
-		case "--type":
+		case '--type':
 			$type = trim($value);
 
 			break;
-		case "--name":
+		case '--name':
 			$name = trim($value);
 
 			break;
-		case "--sort-method":
+		case '--sort-method':
 			$sortMethod = trim($value);
 
 			break;
-		case "--parent-node":
+		case '--parent-node':
 			$parentNode = $value;
 
 			break;
-		case "--tree-id":
+		case '--tree-id':
 			$treeId = $value;
 
 			break;
-		case "--node-type":
+		case '--node-type':
 			$nodeType = trim($value);
 
 			break;
-		case "--graph-id":
+		case '--graph-id':
 			$graphId = $value;
 
 			break;
-		case "--rra-id":
-			$rra_id = $value;
-
-			break;
-		case "--host-id":
+		case '--host-id':
 			$hostId = $value;
 
 			break;
-		case "--quiet":
+		case '--quiet':
 			$quietMode = TRUE;
 
 			break;
-		case "--list-hosts":
+		case '--list-hosts':
 			$displayHosts = TRUE;
 
 			break;
-		case "--list-trees":
+		case '--list-trees':
 			$displayTrees = TRUE;
 
 			break;
-		case "--list-nodes":
+		case '--list-nodes':
 			$displayNodes = TRUE;
 
 			break;
-		case "--list-rras":
-			$displayRRAs = TRUE;
-
-			break;
-		case "--list-graphs":
+		case '--list-graphs':
 			$displayGraphs = TRUE;
 
 			break;
-		case "--host-group-style":
+		case '--host-group-style':
 			$hostGroupStyle = trim($value);
 
 			break;
-		case "--quiet":
+		case '--quiet':
 			$quietMode = TRUE;
 
 			break;
-		case "--version":
-		case "-V":
-		case "-H":
-		case "--help":
+		case '--version':
+		case '-V':
+		case '-v':
+			display_version();
+			exit;
+		case '--help':
+		case '-H':
+		case '-h':
 			display_help();
-			exit(0);
+			exit;
 		default:
 			echo "ERROR: Invalid Argument: ($arg)\n\n";
 			display_help();
@@ -196,38 +195,38 @@ if (sizeof($parms)) {
 		}
 
 		$treeOpts = array();
-		$treeOpts["id"]        = 0; # Zero means create a new one rather than save over an existing one
-		$treeOpts["name"]      = $name;
+		$treeOpts['id']        = 0; # Zero means create a new one rather than save over an existing one
+		$treeOpts['name']      = $name;
 
-		if ($sortMethod == "manual"||
-			$sortMethod == "alpha" ||
-			$sortMethod == "numeric" ||
-			$sortMethod == "natural") {
-			$treeOpts["sort_type"] = $sortMethods[$sortMethod];
+		if ($sortMethod == 'manual'||
+			$sortMethod == 'alpha' ||
+			$sortMethod == 'numeric' ||
+			$sortMethod == 'natural') {
+			$treeOpts['sort_type'] = $sortMethods[$sortMethod];
 		} else {
 			echo "ERROR: Invalid sort-method: ($sortMethod)\n";
 			display_help();
 			exit(1);
 		}
 
-		$existsAlready = db_fetch_cell("select id from graph_tree where name = '$name'");
+		$existsAlready = db_fetch_cell("SELECT id FROM graph_tree WHERE name = '$name'");
 		if ($existsAlready) {
 			echo "ERROR: Not adding tree - it already exists - tree-id: ($existsAlready)\n";
 			exit(1);
 		}
 
-		$treeId = sql_save($treeOpts, "graph_tree");
+		$treeId = sql_save($treeOpts, 'graph_tree');
 
-		sort_tree(SORT_TYPE_TREE, $treeId, $treeOpts["sort_type"]);
+		api_tree_sort_branch(0, $treeId);
 
 		echo "Tree Created - tree-id: ($treeId)\n";
 
 		exit(0);
 	} elseif ($type == 'node') {
 		# Add a new node to a tree
-		if ($nodeType == "header"||
-			$nodeType == "graph" ||
-			$nodeType == "host") {
+		if ($nodeType == 'header'||
+			$nodeType == 'graph' ||
+			$nodeType == 'host') {
 			$itemType = $nodeTypes[$nodeType];
 		} else {
 			echo "ERROR: Invalid node-type: ($nodeType)\n";
@@ -259,9 +258,8 @@ if (sizeof($parms)) {
 				exit(1);
 			}
 
-			# Blank out the graphId, rra_id, hostID and host_grouping_style  fields
+			# Blank out the graphId, hostID and host_grouping_style  fields
 			$graphId        = 0;
-			$rra_id         = 0;
 			$hostId         = 0;
 			$hostGroupStyle = 1;
 		}else if($nodeType == 'graph') {
@@ -270,32 +268,17 @@ if (sizeof($parms)) {
 			$hostId         = 0;
 			$hostGroupStyle = 1;
 
-			# verify rra-id
-			if (!is_numeric($rra_id)) {
-				echo "ERROR: rra-id $rra_id must be numeric > 0\n";
-				display_help();
-				exit(1);
-			} elseif ($rra_id > 0 ) {
-				$rraExists = db_fetch_cell("SELECT id FROM rra WHERE id=$rra_id");
-
-				if (!isset($rraExists)) {
-					echo "ERROR: rra-id $rra_id does not exist\n";
-					exit(1);
-				}
-			}
-			$graphs = db_fetch_assoc("SELECT " .
-				"id " .
-				"FROM graph_local " .
-				"WHERE graph_local.id=" . $graphId);
+			$graphs = db_fetch_assoc('SELECT id 
+				FROM graph_local
+				WHERE graph_local.id=' . $graphId);
 		
 			if (!sizeof($graphs)) {
 				echo "ERROR: No such graph-id ($graphId) exists. Try --list-graphs\n";
 				exit(1);
 			}
 		}else if ($nodeType == 'host') {
-			# Blank out graphId, rra_id, name fields
+			# Blank out graphId, name fields
 			$graphId        = 0;
-			$rra_id         = 0;
 			$name           = '';
 
 			if (!isset($hosts[$hostId])) {
@@ -311,7 +294,7 @@ if (sizeof($parms)) {
 		}
 
 		# $nodeId could be a Header Node, a Graph Node, or a Host node.
-		$nodeId = api_tree_item_save(0, $treeId, $itemType, $parentNode, $name, $graphId, $rra_id, $hostId, $hostGroupStyle, $sortMethods[$sortMethod], false);
+		$nodeId = api_tree_item_save(0, $treeId, $itemType, $parentNode, $name, $graphId, $hostId, $hostGroupStyle, $sortMethods[$sortMethod], false);
 
 		echo "Added Node node-id: ($nodeId)\n";
 
@@ -326,10 +309,16 @@ if (sizeof($parms)) {
 	exit(0);
 }
 
+/*  display_version - displays version information */
+function display_version() {
+	$version = get_cacti_version();
+	echo "Cacti Add Tree Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
+}
+
 function display_help() {
-	echo "Add Tree Script 1.0, Copyright 2004-2012 - The Cacti Group\n\n";
-	echo "A simple command line utility to add objects to a tree in Cacti\n\n";
-	echo "usage: add_tree.php  --type=[tree|node] [type-options] [--quiet]\n\n";
+	display_version();
+
+	echo "\nusage: add_tree.php  --type=[tree|node] [type-options] [--quiet]\n\n";
 	echo "Tree options:\n";
 	echo "    --name=[Tree Name]\n";
 	echo "    --sort-method=[manual|alpha|natural|numeric]\n\n";
@@ -346,14 +335,10 @@ function display_help() {
 	echo "     1 = Graph Template,\n";
 	echo "     2 = Data Query Index)\n\n";
 	echo "Graph node options:\n";
-	echo "    --graph-id=[ID]\n";
-	echo "    [--rra-id=[ID]]\n\n";
+	echo "    --graph-id=[ID]\n\n";
 	echo "List Options:\n";
 	echo "    --list-hosts\n";
 	echo "    --list-trees\n";
 	echo "    --list-nodes --tree-id=[ID]\n";
-	echo "    --list-rras\n";
 	echo "    --list-graphs --host-id=[ID]\n";
 }
-
-?>
